#!/usr/bin/env python
# -*- coding: utf-8 -*-
from django.urls import path
from . import views

urlpatterns = [
    path('imports/', views.imports_database_page, name='imports_database_page'),
    path('workflows/', views.workflows_database_page, name='workflows_database_page'),
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from omeroweb.webclient.decorators import login_required, render_response
import logging
import jwt
import time
import os

logger = logging.getLogger(__name__)

@login_required()
@render_response()
def imports_database_page(request, conn=None, **kwargs):
    metabase_site_url = os.environ.get('METABASE_SITE_URL')
    metabase_secret_key = os.environ.get('METABASE_SECRET_KEY')
    metabase_dashboard_id = os.environ.get('METABASE_IMPORTS_DB_PAGE_DASHBOARD_ID')

    # Get the current user's information
    current_user = conn.getUser()
    username = current_user.getName()
    user_id = current_user.getId()

    # Check if the user is an admin
    is_admin = conn.isAdmin()
    
    # Log admin status
    if is_admin:
        logger.info(f"User {username} (ID: {user_id}) is an admin")
    else:
        logger.info(f"User {username} (ID: {user_id}) is not an admin")

    payload = {
        "resource": {"dashboard": int(metabase_dashboard_id)},
        "params": {
            "user_name": [username],
        },
        "exp": round(time.time()) + (60 * 30)  # 10 minute expiration
    }
    token = jwt.encode(payload, metabase_secret_key, algorithm="HS256")

    context = {
        'metabase_site_url': metabase_site_url,
        'metabase_token': token,
        'template': 'databasepages/webclient_plugins/imports_database_page.html',
        'user_name': username,
        'user_id': user_id,
        'is_admin': is_admin
    }
    return context

@login_required()
@render_response()
def workflows_database_page(request, conn=None, **kwargs):
    metabase_site_url = os.environ.get('METABASE_SITE_URL')
    metabase_secret_key = os.environ.get('METABASE_SECRET_KEY')
    metabase_dashboard_id = os.environ.get('METABASE_WORKFLOWS_DB_PAGE_DASHBOARD_ID')

    # Get the current user's information
    current_user = conn.getUser()
    username = current_user.getName()
    user_id = current_user.getId()

    # Check if the user is an admin
    is_admin = conn.isAdmin()
    
    # Log admin status
    if is_admin:
        logger.info(f"User {username} (ID: {user_id}) is an admin")
    else:
        logger.info(f"User {username} (ID: {user_id}) is not an admin")

    payload = {
        "resource": {"dashboard": int(metabase_dashboard_id)},
        "params": {
            "user": [user_id],
        },
        "exp": round(time.time()) + (60 * 30)  # 10 minute expiration
    }
    token = jwt.encode(payload, metabase_secret_key, algorithm="HS256")

    context = {
        'metabase_site_url': metabase_site_url,
        'metabase_token': token,
        'template': 'databasepages/webclient_plugins/workflows_database_page.html',
        'user_name': username,
        'user_id': user_id,
        'is_admin': is_admin
    }
    return context

@login_required()
@render_response()
def imports_webclient_templates(request, base_template, **kwargs):
    """ Simply return the named template for imports database. """
    template_name = f'databasepages/webgateway/{base_template}.html'
    return {'template': template_name}

@login_required()
@render_response()
def workflows_webclient_templates(request, base_template, **kwargs):
    """ Simply return the named template for workflows database. """
    template_name = f'databasepages/webgateway/{base_template}.html'
    return {'template': template_name}


import os
from shutil import copyfile


def main():
    # Step 1: Add the database-pages configuration to OMERO.web
    config_src = os.path.join(
        os.path.dirname(__file__), '03-database_pages.omero'
    )
    config_dst = '/opt/omero/web/config/03-database_pages.omero'

    try:
        copyfile(config_src, config_dst)
        print(
            f"Successfully added database-pages configuration: "
            f"{config_src} -> {config_dst}"
        )
    except Exception as e:
        print(f"Error adding database-pages configuration: {e}")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2016 University of Dundee.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Aleksandra Tarkowska <A(dot)Tarkowska(at)dundee(dot)ac(dot)uk>,
#
# Version: 1.0

import os
from setuptools import setup, find_packages


# Utility function to read the README file.
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name="omero-database-pages",
    use_scm_version=True,
    setup_requires=['setuptools_scm'],
    packages=find_packages(exclude=['ez_setup']),
    description="A Python plugin for OMERO.web to display database pages",
    long_description=read('README.rst'),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    author='Cellular Imaging Amsterdam UMC',
    author_email='rrosas@amsterdamumc.nl',
    license='AGPL-3.0',
    url="https://github.com/Cellular-Imaging-Amsterdam-UMC/omero-database-pages",
    download_url='https://github.com/Cellular-Imaging-Amsterdam-UMC/omero-database-pages/archive/refs/heads/main.zip',
    keywords=['OMERO.web', 'plugin', 'database pages', 'imports database','workflows database'],
    install_requires=['omero-web>=5.6.0', 'pyjwt'],
    python_requires='>=3',
    include_package_data=True,
    zip_safe=False,
    package_data={
        'database_pages': [
            'templates/databasepages/webclient_plugins/imports_database_page.html',
            'templates/databasepages/webclient_plugins/workflows_database_page.html',
            'static/databasepages/css/database_pages.css',
        ],
    },
    entry_points={
        'console_scripts': [
            'omero-database-pages-setup=database_pages.setup_integration:main',
        ],
    },
)
